==> openshift-model-monitoring-5.7.3-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/QueueConfigFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import java.lang.Integer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface QueueConfigFluent<A extends io.fabric8.openshift.api.model.monitoring.v1.QueueConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getBatchSendDeadline();
  public A withBatchSendDeadline(java.lang.String batchSendDeadline);
  public java.lang.Boolean hasBatchSendDeadline();
  
  /**
   * Method is deprecated. use withBatchSendDeadline instead.
   */
  @java.lang.Deprecated
  public A withNewBatchSendDeadline(java.lang.String arg0);
  public java.lang.Integer getCapacity();
  public A withCapacity(java.lang.Integer capacity);
  public java.lang.Boolean hasCapacity();
  public java.lang.String getMaxBackoff();
  public A withMaxBackoff(java.lang.String maxBackoff);
  public java.lang.Boolean hasMaxBackoff();
  
  /**
   * Method is deprecated. use withMaxBackoff instead.
   */
  @java.lang.Deprecated
  public A withNewMaxBackoff(java.lang.String arg0);
  public java.lang.Integer getMaxRetries();
  public A withMaxRetries(java.lang.Integer maxRetries);
  public java.lang.Boolean hasMaxRetries();
  public java.lang.Integer getMaxSamplesPerSend();
  public A withMaxSamplesPerSend(java.lang.Integer maxSamplesPerSend);
  public java.lang.Boolean hasMaxSamplesPerSend();
  public java.lang.Integer getMaxShards();
  public A withMaxShards(java.lang.Integer maxShards);
  public java.lang.Boolean hasMaxShards();
  public java.lang.String getMinBackoff();
  public A withMinBackoff(java.lang.String minBackoff);
  public java.lang.Boolean hasMinBackoff();
  
  /**
   * Method is deprecated. use withMinBackoff instead.
   */
  @java.lang.Deprecated
  public A withNewMinBackoff(java.lang.String arg0);
  public java.lang.Integer getMinShards();
  public A withMinShards(java.lang.Integer minShards);
  public java.lang.Boolean hasMinShards();
  
}

==> openshift-model-monitoring-5.12.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/QueueConfigFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import java.lang.Integer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface QueueConfigFluent<A extends io.fabric8.openshift.api.model.monitoring.v1.QueueConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getBatchSendDeadline();
  public A withBatchSendDeadline(java.lang.String batchSendDeadline);
  public java.lang.Boolean hasBatchSendDeadline();
  
  /**
   * Method is deprecated. use withBatchSendDeadline instead.
   */
  @java.lang.Deprecated
  public A withNewBatchSendDeadline(java.lang.String arg0);
  public java.lang.Integer getCapacity();
  public A withCapacity(java.lang.Integer capacity);
  public java.lang.Boolean hasCapacity();
  public java.lang.String getMaxBackoff();
  public A withMaxBackoff(java.lang.String maxBackoff);
  public java.lang.Boolean hasMaxBackoff();
  
  /**
   * Method is deprecated. use withMaxBackoff instead.
   */
  @java.lang.Deprecated
  public A withNewMaxBackoff(java.lang.String arg0);
  public java.lang.Integer getMaxRetries();
  public A withMaxRetries(java.lang.Integer maxRetries);
  public java.lang.Boolean hasMaxRetries();
  public java.lang.Integer getMaxSamplesPerSend();
  public A withMaxSamplesPerSend(java.lang.Integer maxSamplesPerSend);
  public java.lang.Boolean hasMaxSamplesPerSend();
  public java.lang.Integer getMaxShards();
  public A withMaxShards(java.lang.Integer maxShards);
  public java.lang.Boolean hasMaxShards();
  public java.lang.String getMinBackoff();
  public A withMinBackoff(java.lang.String minBackoff);
  public java.lang.Boolean hasMinBackoff();
  
  /**
   * Method is deprecated. use withMinBackoff instead.
   */
  @java.lang.Deprecated
  public A withNewMinBackoff(java.lang.String arg0);
  public java.lang.Integer getMinShards();
  public A withMinShards(java.lang.Integer minShards);
  public java.lang.Boolean hasMinShards();
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  
}
